summaryrefslogtreecommitdiffstats
path: root/kdat/Tape.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:52:44 -0600
committerSlávek Banko <slavek.banko@axis.cz>2012-06-03 20:26:21 +0200
commit239cc9b83ce0d6dd5216aeb01a82e0d23a0a3595 (patch)
treeb9679d63b6a1004d9983259d41303b5a88a1621a /kdat/Tape.h
parent1754e4db964431e721e805a923b689b6c92960e4 (diff)
downloadtdeadmin-239cc9b83ce0d6dd5216aeb01a82e0d23a0a3595.tar.gz
tdeadmin-239cc9b83ce0d6dd5216aeb01a82e0d23a0a3595.zip
Remove additional unneeded tq method conversions
(cherry picked from commit 6b7a8ff33a6383be4a9dea3c4225d142aab79b78)
Diffstat (limited to 'kdat/Tape.h')
-rw-r--r--kdat/Tape.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdat/Tape.h b/kdat/Tape.h
index 153561e..335619c 100644
--- a/kdat/Tape.h
+++ b/kdat/Tape.h
@@ -34,7 +34,7 @@ class Tape {
int _mtime;
TQString _name;
int _size;
- TQPtrList<Archive> _tqchildren;
+ TQPtrList<Archive> _children;
FILE* _fptr;
@@ -148,7 +148,7 @@ public:
void removeChild( Archive* archive );
/**
* Recursively destroy all tqchildren of the tape index.
*/
void clear();
};
@@ -148,7 +148,7 @@ public:
void removeChild( Archive* archive );
/**
- * Recursively destroy all tqchildren of the tape index.
+ * Recursively destroy all children of the tape index.
*/
void clear();